@@ -469,7 +469,7 @@ class DataCounterResetter(QtGui.QWidget):
             action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
                              alarm.ACTION_TYPE_EXEC)
             if eventInfo["content"] == gprsdataresetter:
-                action.command = str("/opt/alarmed/gprsdataresetter")
+                action.command = str("/opt/alarmed/gprsdataresetter.py")
             
         if eventInfo["interval"] != only_once:
             recurrence = event.add_recurrences(1)[0]
@@ -530,7 +530,11 @@ class DataCounterResetter(QtGui.QWidget):
 
         if self.editing:
             old_id = self.eventList.currentItem().eventInfo["id"]
-        eventInfo["id"] = str(alarm.add_event(event))
+            
+        try:
+            eventInfo["id"] = str(alarm.add_event(event))
+        except alarm.invalidEventException:
+            
 
         # Add event to gui list
         newEventString = self.generateEventString(eventInfo)
